<?php

namespace Drupal\custom_db_table_views\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines the configuration export form.
 */
class DBTableExportForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'config_customtable_form';
  }

   /** 
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'custom_db_table_views.settings',
    ];
  }
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
	 $form = parent::buildForm($form, $form_state);
	 $config = $this->config('custom_db_table_views.settings');
	$form['db_server_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Database Server Name'),
    ];
	$form['db_user_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Database User Name'),
    ];
	$form['db_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Database Name'),
	  '#required' => true,
	  '#default_value' => $config->get('db_name'),
    ];
	$form['db_password'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Database Password'),
    ];
	$form['db_table_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Database Table Name'),
	  '#required' => true,
	  '#default_value' => $config->get('db_table_name'),
    ];
	$form['db_views_name'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Views Name'),
	  '#required' => true,
	  '#default_value' => $config->get('db_views_name'),
    ];
	$form['user_note'] = [
      '#markup' => '<em>If database is on other server then configure some changes in settings.php and also in this page .<a href="http://localhost/drupal8/admin/config/settings-custom-db" target="_blank">Click Here</a> to see the changes example.</em>',
    ];
     return $form;
  
  }

/** 
  * {@inheritdoc}
  */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    
   $config = $this->config('custom_db_table_views.settings');
   if($form_state->getValue('db_server_name')!='')
   {
	  $config->set('db_server_name', $form_state->getValue('db_server_name'));
   }
   if($form_state->getValue('db_user_name')!='')
   {
	  $config->set('db_user_name', $form_state->getValue('db_user_name'));
   }
   if($form_state->getValue('db_password')!='')
   {
	  $config->set('db_password', $form_state->getValue('db_password'));
   }
   $config->set('db_name', $form_state->getValue('db_name'));
   $config->set('db_table_name', $form_state->getValue('db_table_name'));
   $config->set('db_views_name', $form_state->getValue('db_views_name'));
   $config->save();
 
    return parent::submitForm($form, $form_state);
  }

}
